Data Readers
============

TBW
---
.. automodule:: lsl.reader.tbw
   :members:

TBN
---
.. automodule:: lsl.reader.tbn
   :members:

DRX
---
.. automodule:: lsl.reader.drx
   :members:

Reader Error Codes
------------------
.. automodule:: lsl.reader.errors
   :members:

Reader Ring Buffer
==================
.. automodule:: lsl.reader.buffer
   :show-inheritance:
   :members:

